@@ -335,7 +335,7 @@ settings_dialog_new (GpsDataLoggerWidget * self)
     time_selector = hildon_touch_selector_new_text ();
     text = g_malloc0(25);
     for (i = 1; i <= 25; i++ ) {
-        g_sprintf(text, "%d seconds", i * AUTO_PAUSE_TIME_MULTIPLIER);
+        g_sprintf(text, _("%d seconds"), i * AUTO_PAUSE_TIME_MULTIPLIER);
 	hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (time_selector),
 			text);
     }
