@@ -43,6 +43,7 @@ typedef enum {
 	APP_STATE_IDLE = 0,
 	APP_STATE_STARTING,
 	APP_STATE_RECORDING,
+	APP_STATE_AUTO_PAUSED,
 	APP_STATE_PAUSED,
 	APP_STATE_STOPPING
 } APP_STATE;
@@ -57,9 +58,11 @@ struct _GpsDataLoggerWidget
 	gboolean	has_comma_as_decimal_point;
 	gint	 	app_state;
 	gint		points_recorded_in_current_segment;
+	double		auto_pause_time_mark;
 	LocationGPSDControl *control;
 	LocationGPSDevice *device;
 	FILE		*file;
+	gchar		*path;
 #ifdef DEBUG
 	FILE		*logfile;
 #endif
@@ -71,6 +74,9 @@ struct _GpsDataLoggerWidget
 	GtkWidget 	*chk_method_acwp;
 	GtkWidget 	*chk_method_cwp;
 	GtkWidget 	*pkr_interval;
+	GtkWidget	*chb_auto_pause;
+	GtkWidget	*pkr_pause_speed_threshold;
+	GtkWidget	*pkr_pause_time_threshold;
 	GtkWidget 	*btn_path;
 	/* Desktop widget */
 	GtkWidget 	*background;
@@ -83,6 +89,7 @@ struct _GpsDataLoggerWidget
 	GdkPixbuf	*gps_on_icon;
 	GdkPixbuf	*gps_off_icon;
 	GtkWidget	*gps_status;
+	GtkWidget	*auto_pause_status;
 	GtkWidget	*button_rec;
 	GtkWidget	*button_stop;
 	gboolean	rec_button_down;
